/**
 * ./src/components/location.tsx
 * penguins-eggs v.10.0.0 / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import React from 'react';
import Title from './title.js';
import Steps from './steps.js';
import { Text, Box, Newline } from 'ink';
import yaml from 'js-yaml';
import fs from 'fs';
// pjson
import { createRequire } from 'module';
const require = createRequire(import.meta.url);
const pjson = require('../../package.json');
export default function Location({ region = '', zone = '', language = '', dateNumbers = '' }) {
    let productName = 'unknown';
    let version = 'x.x.x';
    let configRoot = '/etc/penguins-eggs.d/krill/';
    if (fs.existsSync('/etc/calamares/settings.conf')) {
        configRoot = '/etc/calamares/';
    }
    const settings = yaml.load(fs.readFileSync(configRoot + 'settings.conf', 'utf-8'));
    const branding = settings.branding;
    const calamares = yaml.load(fs.readFileSync(configRoot + 'branding/' + branding + '/branding.desc', 'utf-8'));
    productName = calamares.strings.productName;
    version = calamares.strings.version;
    /**
    * totale width=74
    * step width=15
    * finestra with=59
    */
    return (React.createElement(React.Fragment, null,
        React.createElement(Title, null),
        React.createElement(Box, { width: 74, height: 11, borderStyle: "round", flexDirection: "column" },
            React.createElement(Box, { flexDirection: "column" },
                React.createElement(Box, { flexDirection: "row" },
                    React.createElement(Steps, { step: 2 }),
                    React.createElement(Box, { flexDirection: "column" },
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Select your timezone")),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Area: "),
                            React.createElement(Text, { color: "cyan" },
                                region,
                                " ")),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Zone: "),
                            React.createElement(Text, { color: "cyan" }, zone)),
                        React.createElement(Newline, null),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Language: "),
                            React.createElement(Text, { color: "cyan" }, language)),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Locale date/numbers: "),
                            React.createElement(Text, { color: "cyan" }, language))))))));
}
