/**
 * ./src/components/partitions.tsx
 * penguins-eggs v.10.0.0 / ecmascript 2020
 * author: Piero Proietti
 * email: piero.proietti@gmail.com
 * license: MIT
 */
import React from 'react';
import Title from './title.js';
import Steps from './steps.js';
import yaml from 'js-yaml';
import fs from 'fs';
import { Text, Box } from 'ink';
export default function Partitions({ installationDevice, installationMode, filesystemType, userSwapChoice }) {
    let installer = 'krill';
    let productName = '';
    let version = '';
    let configRoot = '/etc/penguins-eggs.d/krill/';
    if (fs.existsSync('/etc/calamares/settings.conf')) {
        configRoot = '/etc/calamares/';
    }
    const settings = yaml.load(fs.readFileSync(configRoot + 'settings.conf', 'utf-8'));
    const branding = settings.branding;
    const calamares = yaml.load(fs.readFileSync(configRoot + 'branding/' + branding + '/branding.desc', 'utf-8'));
    productName = calamares.strings.productName;
    version = calamares.strings.version;
    /**
    * totale width=74
    * step width=15
    * finestra with=59
    */
    let bios = 'standard';
    if (fs.existsSync('/sys/firmware/efi/efivars')) {
        bios = 'UEFI';
    }
    let partitions = {};
    if (fs.existsSync(configRoot + 'modules/partition.conf')) {
        partitions = yaml.load(fs.readFileSync(configRoot + 'modules/partition.conf', 'utf-8'));
    }
    else {
        partitions.initialSwapChoice = 'small';
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(Title, null),
        React.createElement(Box, { width: 74, height: 11, borderStyle: "round", flexDirection: "column" },
            React.createElement(Box, { flexDirection: "column" },
                React.createElement(Box, { flexDirection: "row" },
                    React.createElement(Steps, { step: 4 }),
                    React.createElement(Box, { flexDirection: "column" }),
                    React.createElement(Box, { flexDirection: "column" },
                        React.createElement(Box, { flexDirection: "row" },
                            React.createElement(Text, { underline: true }, "erase disk:"),
                            React.createElement(Text, null, " this will "),
                            React.createElement(Text, { color: "red" }, "delete "),
                            React.createElement(Text, null, "all data currently")),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "present on the selected storage device")),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "BIOS: "),
                            React.createElement(Text, { color: "cyan" }, bios)),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Installation device: "),
                            React.createElement(Text, { color: "cyan" }, installationDevice)),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Installation mode: "),
                            React.createElement(Text, { color: "cyan" }, installationMode)),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "Filesystem: "),
                            React.createElement(Text, { color: "cyan" }, filesystemType)),
                        React.createElement(Box, null,
                            React.createElement(Text, null, "User swap choice: : "),
                            React.createElement(Text, { color: "cyan" }, userSwapChoice))))))));
}
