import { createAggregatedClient } from "@smithy/smithy-client";
import { CloudFrontClient } from "./CloudFrontClient";
import { AssociateAliasCommand, } from "./commands/AssociateAliasCommand";
import { CopyDistributionCommand, } from "./commands/CopyDistributionCommand";
import { CreateCachePolicyCommand, } from "./commands/CreateCachePolicyCommand";
import { CreateCloudFrontOriginAccessIdentityCommand, } from "./commands/CreateCloudFrontOriginAccessIdentityCommand";
import { CreateContinuousDeploymentPolicyCommand, } from "./commands/CreateContinuousDeploymentPolicyCommand";
import { CreateDistributionCommand, } from "./commands/CreateDistributionCommand";
import { CreateDistributionWithTagsCommand, } from "./commands/CreateDistributionWithTagsCommand";
import { CreateFieldLevelEncryptionConfigCommand, } from "./commands/CreateFieldLevelEncryptionConfigCommand";
import { CreateFieldLevelEncryptionProfileCommand, } from "./commands/CreateFieldLevelEncryptionProfileCommand";
import { CreateFunctionCommand, } from "./commands/CreateFunctionCommand";
import { CreateInvalidationCommand, } from "./commands/CreateInvalidationCommand";
import { CreateKeyGroupCommand, } from "./commands/CreateKeyGroupCommand";
import { CreateKeyValueStoreCommand, } from "./commands/CreateKeyValueStoreCommand";
import { CreateMonitoringSubscriptionCommand, } from "./commands/CreateMonitoringSubscriptionCommand";
import { CreateOriginAccessControlCommand, } from "./commands/CreateOriginAccessControlCommand";
import { CreateOriginRequestPolicyCommand, } from "./commands/CreateOriginRequestPolicyCommand";
import { CreatePublicKeyCommand, } from "./commands/CreatePublicKeyCommand";
import { CreateRealtimeLogConfigCommand, } from "./commands/CreateRealtimeLogConfigCommand";
import { CreateResponseHeadersPolicyCommand, } from "./commands/CreateResponseHeadersPolicyCommand";
import { CreateStreamingDistributionCommand, } from "./commands/CreateStreamingDistributionCommand";
import { CreateStreamingDistributionWithTagsCommand, } from "./commands/CreateStreamingDistributionWithTagsCommand";
import { DeleteCachePolicyCommand, } from "./commands/DeleteCachePolicyCommand";
import { DeleteCloudFrontOriginAccessIdentityCommand, } from "./commands/DeleteCloudFrontOriginAccessIdentityCommand";
import { DeleteContinuousDeploymentPolicyCommand, } from "./commands/DeleteContinuousDeploymentPolicyCommand";
import { DeleteDistributionCommand, } from "./commands/DeleteDistributionCommand";
import { DeleteFieldLevelEncryptionConfigCommand, } from "./commands/DeleteFieldLevelEncryptionConfigCommand";
import { DeleteFieldLevelEncryptionProfileCommand, } from "./commands/DeleteFieldLevelEncryptionProfileCommand";
import { DeleteFunctionCommand, } from "./commands/DeleteFunctionCommand";
import { DeleteKeyGroupCommand, } from "./commands/DeleteKeyGroupCommand";
import { DeleteKeyValueStoreCommand, } from "./commands/DeleteKeyValueStoreCommand";
import { DeleteMonitoringSubscriptionCommand, } from "./commands/DeleteMonitoringSubscriptionCommand";
import { DeleteOriginAccessControlCommand, } from "./commands/DeleteOriginAccessControlCommand";
import { DeleteOriginRequestPolicyCommand, } from "./commands/DeleteOriginRequestPolicyCommand";
import { DeletePublicKeyCommand, } from "./commands/DeletePublicKeyCommand";
import { DeleteRealtimeLogConfigCommand, } from "./commands/DeleteRealtimeLogConfigCommand";
import { DeleteResponseHeadersPolicyCommand, } from "./commands/DeleteResponseHeadersPolicyCommand";
import { DeleteStreamingDistributionCommand, } from "./commands/DeleteStreamingDistributionCommand";
import { DescribeFunctionCommand, } from "./commands/DescribeFunctionCommand";
import { DescribeKeyValueStoreCommand, } from "./commands/DescribeKeyValueStoreCommand";
import { GetCachePolicyCommand, } from "./commands/GetCachePolicyCommand";
import { GetCachePolicyConfigCommand, } from "./commands/GetCachePolicyConfigCommand";
import { GetCloudFrontOriginAccessIdentityCommand, } from "./commands/GetCloudFrontOriginAccessIdentityCommand";
import { GetCloudFrontOriginAccessIdentityConfigCommand, } from "./commands/GetCloudFrontOriginAccessIdentityConfigCommand";
import { GetContinuousDeploymentPolicyCommand, } from "./commands/GetContinuousDeploymentPolicyCommand";
import { GetContinuousDeploymentPolicyConfigCommand, } from "./commands/GetContinuousDeploymentPolicyConfigCommand";
import { GetDistributionCommand, } from "./commands/GetDistributionCommand";
import { GetDistributionConfigCommand, } from "./commands/GetDistributionConfigCommand";
import { GetFieldLevelEncryptionCommand, } from "./commands/GetFieldLevelEncryptionCommand";
import { GetFieldLevelEncryptionConfigCommand, } from "./commands/GetFieldLevelEncryptionConfigCommand";
import { GetFieldLevelEncryptionProfileCommand, } from "./commands/GetFieldLevelEncryptionProfileCommand";
import { GetFieldLevelEncryptionProfileConfigCommand, } from "./commands/GetFieldLevelEncryptionProfileConfigCommand";
import { GetFunctionCommand } from "./commands/GetFunctionCommand";
import { GetInvalidationCommand, } from "./commands/GetInvalidationCommand";
import { GetKeyGroupCommand } from "./commands/GetKeyGroupCommand";
import { GetKeyGroupConfigCommand, } from "./commands/GetKeyGroupConfigCommand";
import { GetMonitoringSubscriptionCommand, } from "./commands/GetMonitoringSubscriptionCommand";
import { GetOriginAccessControlCommand, } from "./commands/GetOriginAccessControlCommand";
import { GetOriginAccessControlConfigCommand, } from "./commands/GetOriginAccessControlConfigCommand";
import { GetOriginRequestPolicyCommand, } from "./commands/GetOriginRequestPolicyCommand";
import { GetOriginRequestPolicyConfigCommand, } from "./commands/GetOriginRequestPolicyConfigCommand";
import { GetPublicKeyCommand, } from "./commands/GetPublicKeyCommand";
import { GetPublicKeyConfigCommand, } from "./commands/GetPublicKeyConfigCommand";
import { GetRealtimeLogConfigCommand, } from "./commands/GetRealtimeLogConfigCommand";
import { GetResponseHeadersPolicyCommand, } from "./commands/GetResponseHeadersPolicyCommand";
import { GetResponseHeadersPolicyConfigCommand, } from "./commands/GetResponseHeadersPolicyConfigCommand";
import { GetStreamingDistributionCommand, } from "./commands/GetStreamingDistributionCommand";
import { GetStreamingDistributionConfigCommand, } from "./commands/GetStreamingDistributionConfigCommand";
import { ListCachePoliciesCommand, } from "./commands/ListCachePoliciesCommand";
import { ListCloudFrontOriginAccessIdentitiesCommand, } from "./commands/ListCloudFrontOriginAccessIdentitiesCommand";
import { ListConflictingAliasesCommand, } from "./commands/ListConflictingAliasesCommand";
import { ListContinuousDeploymentPoliciesCommand, } from "./commands/ListContinuousDeploymentPoliciesCommand";
import { ListDistributionsByCachePolicyIdCommand, } from "./commands/ListDistributionsByCachePolicyIdCommand";
import { ListDistributionsByKeyGroupCommand, } from "./commands/ListDistributionsByKeyGroupCommand";
import { ListDistributionsByOriginRequestPolicyIdCommand, } from "./commands/ListDistributionsByOriginRequestPolicyIdCommand";
import { ListDistributionsByRealtimeLogConfigCommand, } from "./commands/ListDistributionsByRealtimeLogConfigCommand";
import { ListDistributionsByResponseHeadersPolicyIdCommand, } from "./commands/ListDistributionsByResponseHeadersPolicyIdCommand";
import { ListDistributionsByWebACLIdCommand, } from "./commands/ListDistributionsByWebACLIdCommand";
import { ListDistributionsCommand, } from "./commands/ListDistributionsCommand";
import { ListFieldLevelEncryptionConfigsCommand, } from "./commands/ListFieldLevelEncryptionConfigsCommand";
import { ListFieldLevelEncryptionProfilesCommand, } from "./commands/ListFieldLevelEncryptionProfilesCommand";
import { ListFunctionsCommand, } from "./commands/ListFunctionsCommand";
import { ListInvalidationsCommand, } from "./commands/ListInvalidationsCommand";
import { ListKeyGroupsCommand, } from "./commands/ListKeyGroupsCommand";
import { ListKeyValueStoresCommand, } from "./commands/ListKeyValueStoresCommand";
import { ListOriginAccessControlsCommand, } from "./commands/ListOriginAccessControlsCommand";
import { ListOriginRequestPoliciesCommand, } from "./commands/ListOriginRequestPoliciesCommand";
import { ListPublicKeysCommand, } from "./commands/ListPublicKeysCommand";
import { ListRealtimeLogConfigsCommand, } from "./commands/ListRealtimeLogConfigsCommand";
import { ListResponseHeadersPoliciesCommand, } from "./commands/ListResponseHeadersPoliciesCommand";
import { ListStreamingDistributionsCommand, } from "./commands/ListStreamingDistributionsCommand";
import { ListTagsForResourceCommand, } from "./commands/ListTagsForResourceCommand";
import { PublishFunctionCommand, } from "./commands/PublishFunctionCommand";
import { TagResourceCommand } from "./commands/TagResourceCommand";
import { TestFunctionCommand, } from "./commands/TestFunctionCommand";
import { UntagResourceCommand, } from "./commands/UntagResourceCommand";
import { UpdateCachePolicyCommand, } from "./commands/UpdateCachePolicyCommand";
import { UpdateCloudFrontOriginAccessIdentityCommand, } from "./commands/UpdateCloudFrontOriginAccessIdentityCommand";
import { UpdateContinuousDeploymentPolicyCommand, } from "./commands/UpdateContinuousDeploymentPolicyCommand";
import { UpdateDistributionCommand, } from "./commands/UpdateDistributionCommand";
import { UpdateDistributionWithStagingConfigCommand, } from "./commands/UpdateDistributionWithStagingConfigCommand";
import { UpdateFieldLevelEncryptionConfigCommand, } from "./commands/UpdateFieldLevelEncryptionConfigCommand";
import { UpdateFieldLevelEncryptionProfileCommand, } from "./commands/UpdateFieldLevelEncryptionProfileCommand";
import { UpdateFunctionCommand, } from "./commands/UpdateFunctionCommand";
import { UpdateKeyGroupCommand, } from "./commands/UpdateKeyGroupCommand";
import { UpdateKeyValueStoreCommand, } from "./commands/UpdateKeyValueStoreCommand";
import { UpdateOriginAccessControlCommand, } from "./commands/UpdateOriginAccessControlCommand";
import { UpdateOriginRequestPolicyCommand, } from "./commands/UpdateOriginRequestPolicyCommand";
import { UpdatePublicKeyCommand, } from "./commands/UpdatePublicKeyCommand";
import { UpdateRealtimeLogConfigCommand, } from "./commands/UpdateRealtimeLogConfigCommand";
import { UpdateResponseHeadersPolicyCommand, } from "./commands/UpdateResponseHeadersPolicyCommand";
import { UpdateStreamingDistributionCommand, } from "./commands/UpdateStreamingDistributionCommand";
const commands = {
    AssociateAliasCommand,
    CopyDistributionCommand,
    CreateCachePolicyCommand,
    CreateCloudFrontOriginAccessIdentityCommand,
    CreateContinuousDeploymentPolicyCommand,
    CreateDistributionCommand,
    CreateDistributionWithTagsCommand,
    CreateFieldLevelEncryptionConfigCommand,
    CreateFieldLevelEncryptionProfileCommand,
    CreateFunctionCommand,
    CreateInvalidationCommand,
    CreateKeyGroupCommand,
    CreateKeyValueStoreCommand,
    CreateMonitoringSubscriptionCommand,
    CreateOriginAccessControlCommand,
    CreateOriginRequestPolicyCommand,
    CreatePublicKeyCommand,
    CreateRealtimeLogConfigCommand,
    CreateResponseHeadersPolicyCommand,
    CreateStreamingDistributionCommand,
    CreateStreamingDistributionWithTagsCommand,
    DeleteCachePolicyCommand,
    DeleteCloudFrontOriginAccessIdentityCommand,
    DeleteContinuousDeploymentPolicyCommand,
    DeleteDistributionCommand,
    DeleteFieldLevelEncryptionConfigCommand,
    DeleteFieldLevelEncryptionProfileCommand,
    DeleteFunctionCommand,
    DeleteKeyGroupCommand,
    DeleteKeyValueStoreCommand,
    DeleteMonitoringSubscriptionCommand,
    DeleteOriginAccessControlCommand,
    DeleteOriginRequestPolicyCommand,
    DeletePublicKeyCommand,
    DeleteRealtimeLogConfigCommand,
    DeleteResponseHeadersPolicyCommand,
    DeleteStreamingDistributionCommand,
    DescribeFunctionCommand,
    DescribeKeyValueStoreCommand,
    GetCachePolicyCommand,
    GetCachePolicyConfigCommand,
    GetCloudFrontOriginAccessIdentityCommand,
    GetCloudFrontOriginAccessIdentityConfigCommand,
    GetContinuousDeploymentPolicyCommand,
    GetContinuousDeploymentPolicyConfigCommand,
    GetDistributionCommand,
    GetDistributionConfigCommand,
    GetFieldLevelEncryptionCommand,
    GetFieldLevelEncryptionConfigCommand,
    GetFieldLevelEncryptionProfileCommand,
    GetFieldLevelEncryptionProfileConfigCommand,
    GetFunctionCommand,
    GetInvalidationCommand,
    GetKeyGroupCommand,
    GetKeyGroupConfigCommand,
    GetMonitoringSubscriptionCommand,
    GetOriginAccessControlCommand,
    GetOriginAccessControlConfigCommand,
    GetOriginRequestPolicyCommand,
    GetOriginRequestPolicyConfigCommand,
    GetPublicKeyCommand,
    GetPublicKeyConfigCommand,
    GetRealtimeLogConfigCommand,
    GetResponseHeadersPolicyCommand,
    GetResponseHeadersPolicyConfigCommand,
    GetStreamingDistributionCommand,
    GetStreamingDistributionConfigCommand,
    ListCachePoliciesCommand,
    ListCloudFrontOriginAccessIdentitiesCommand,
    ListConflictingAliasesCommand,
    ListContinuousDeploymentPoliciesCommand,
    ListDistributionsCommand,
    ListDistributionsByCachePolicyIdCommand,
    ListDistributionsByKeyGroupCommand,
    ListDistributionsByOriginRequestPolicyIdCommand,
    ListDistributionsByRealtimeLogConfigCommand,
    ListDistributionsByResponseHeadersPolicyIdCommand,
    ListDistributionsByWebACLIdCommand,
    ListFieldLevelEncryptionConfigsCommand,
    ListFieldLevelEncryptionProfilesCommand,
    ListFunctionsCommand,
    ListInvalidationsCommand,
    ListKeyGroupsCommand,
    ListKeyValueStoresCommand,
    ListOriginAccessControlsCommand,
    ListOriginRequestPoliciesCommand,
    ListPublicKeysCommand,
    ListRealtimeLogConfigsCommand,
    ListResponseHeadersPoliciesCommand,
    ListStreamingDistributionsCommand,
    ListTagsForResourceCommand,
    PublishFunctionCommand,
    TagResourceCommand,
    TestFunctionCommand,
    UntagResourceCommand,
    UpdateCachePolicyCommand,
    UpdateCloudFrontOriginAccessIdentityCommand,
    UpdateContinuousDeploymentPolicyCommand,
    UpdateDistributionCommand,
    UpdateDistributionWithStagingConfigCommand,
    UpdateFieldLevelEncryptionConfigCommand,
    UpdateFieldLevelEncryptionProfileCommand,
    UpdateFunctionCommand,
    UpdateKeyGroupCommand,
    UpdateKeyValueStoreCommand,
    UpdateOriginAccessControlCommand,
    UpdateOriginRequestPolicyCommand,
    UpdatePublicKeyCommand,
    UpdateRealtimeLogConfigCommand,
    UpdateResponseHeadersPolicyCommand,
    UpdateStreamingDistributionCommand,
};
export class CloudFront extends CloudFrontClient {
}
createAggregatedClient(commands, CloudFront);
