import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { CloudFrontServiceException as __BaseException } from "./CloudFrontServiceException";
import {
  ActiveTrustedSigners,
  Aliases,
  AliasICPRecordal,
  CacheBehaviors,
  CachePolicy,
  CachePolicyConfig,
  CachePolicyList,
  CachePolicyType,
  CloudFrontOriginAccessIdentity,
  CloudFrontOriginAccessIdentityConfig,
  ContentTypeProfileConfig,
  ContinuousDeploymentPolicy,
  ContinuousDeploymentPolicyConfig,
  CustomErrorResponses,
  DefaultCacheBehavior,
  Distribution,
  DistributionConfig,
  EncryptionEntities,
  EndPoint,
  FieldLevelEncryption,
  FieldLevelEncryptionConfig,
  FieldLevelEncryptionProfile,
  FieldLevelEncryptionProfileConfig,
  FunctionConfig,
  FunctionStage,
  FunctionSummary,
  HttpVersion,
  Invalidation,
  KeyGroup,
  KeyGroupConfig,
  KeyValueStore,
  MonitoringSubscription,
  OriginAccessControl,
  OriginAccessControlConfig,
  OriginAccessControlOriginTypes,
  OriginAccessControlSigningBehaviors,
  OriginAccessControlSigningProtocols,
  OriginGroups,
  OriginRequestPolicy,
  OriginRequestPolicyConfig,
  Origins,
  PriceClass,
  PublicKey,
  PublicKeyConfig,
  QueryArgProfileConfig,
  RealtimeLogConfig,
  ResponseHeadersPolicyContentSecurityPolicy,
  ResponseHeadersPolicyContentTypeOptions,
  ResponseHeadersPolicyCorsConfig,
  ResponseHeadersPolicyCustomHeadersConfig,
  ResponseHeadersPolicyRemoveHeadersConfig,
  Restrictions,
  Tags,
  TrustedSigners,
  ViewerCertificate,
} from "./models_0";
export declare const FrameOptionsList: {
  readonly DENY: "DENY";
  readonly SAMEORIGIN: "SAMEORIGIN";
};
export type FrameOptionsList =
  (typeof FrameOptionsList)[keyof typeof FrameOptionsList];
export interface ResponseHeadersPolicyFrameOptions {
  Override: boolean | undefined;
  FrameOption: FrameOptionsList | undefined;
}
export declare const ReferrerPolicyList: {
  readonly no_referrer: "no-referrer";
  readonly no_referrer_when_downgrade: "no-referrer-when-downgrade";
  readonly origin: "origin";
  readonly origin_when_cross_origin: "origin-when-cross-origin";
  readonly same_origin: "same-origin";
  readonly strict_origin: "strict-origin";
  readonly strict_origin_when_cross_origin: "strict-origin-when-cross-origin";
  readonly unsafe_url: "unsafe-url";
};
export type ReferrerPolicyList =
  (typeof ReferrerPolicyList)[keyof typeof ReferrerPolicyList];
export interface ResponseHeadersPolicyReferrerPolicy {
  Override: boolean | undefined;
  ReferrerPolicy: ReferrerPolicyList | undefined;
}
export interface ResponseHeadersPolicyStrictTransportSecurity {
  Override: boolean | undefined;
  IncludeSubdomains?: boolean;
  Preload?: boolean;
  AccessControlMaxAgeSec: number | undefined;
}
export interface ResponseHeadersPolicyXSSProtection {
  Override: boolean | undefined;
  Protection: boolean | undefined;
  ModeBlock?: boolean;
  ReportUri?: string;
}
export interface ResponseHeadersPolicySecurityHeadersConfig {
  XSSProtection?: ResponseHeadersPolicyXSSProtection;
  FrameOptions?: ResponseHeadersPolicyFrameOptions;
  ReferrerPolicy?: ResponseHeadersPolicyReferrerPolicy;
  ContentSecurityPolicy?: ResponseHeadersPolicyContentSecurityPolicy;
  ContentTypeOptions?: ResponseHeadersPolicyContentTypeOptions;
  StrictTransportSecurity?: ResponseHeadersPolicyStrictTransportSecurity;
}
export interface ResponseHeadersPolicyServerTimingHeadersConfig {
  Enabled: boolean | undefined;
  SamplingRate?: number;
}
export interface ResponseHeadersPolicyConfig {
  Comment?: string;
  Name: string | undefined;
  CorsConfig?: ResponseHeadersPolicyCorsConfig;
  SecurityHeadersConfig?: ResponseHeadersPolicySecurityHeadersConfig;
  ServerTimingHeadersConfig?: ResponseHeadersPolicyServerTimingHeadersConfig;
  CustomHeadersConfig?: ResponseHeadersPolicyCustomHeadersConfig;
  RemoveHeadersConfig?: ResponseHeadersPolicyRemoveHeadersConfig;
}
export interface CreateResponseHeadersPolicyRequest {
  ResponseHeadersPolicyConfig: ResponseHeadersPolicyConfig | undefined;
}
export interface ResponseHeadersPolicy {
  Id: string | undefined;
  LastModifiedTime: Date | undefined;
  ResponseHeadersPolicyConfig: ResponseHeadersPolicyConfig | undefined;
}
export interface CreateResponseHeadersPolicyResult {
  ResponseHeadersPolicy?: ResponseHeadersPolicy;
  Location?: string;
  ETag?: string;
}
export declare class ResponseHeadersPolicyAlreadyExists extends __BaseException {
  readonly name: "ResponseHeadersPolicyAlreadyExists";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      ResponseHeadersPolicyAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooLongCSPInResponseHeadersPolicy extends __BaseException {
  readonly name: "TooLongCSPInResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      TooLongCSPInResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyCustomHeadersInResponseHeadersPolicy extends __BaseException {
  readonly name: "TooManyCustomHeadersInResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      TooManyCustomHeadersInResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyRemoveHeadersInResponseHeadersPolicy extends __BaseException {
  readonly name: "TooManyRemoveHeadersInResponseHeadersPolicy";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      TooManyRemoveHeadersInResponseHeadersPolicy,
      __BaseException
    >
  );
}
export declare class TooManyResponseHeadersPolicies extends __BaseException {
  readonly name: "TooManyResponseHeadersPolicies";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<TooManyResponseHeadersPolicies, __BaseException>
  );
}
export interface StreamingLoggingConfig {
  Enabled: boolean | undefined;
  Bucket: string | undefined;
  Prefix: string | undefined;
}
export interface S3Origin {
  DomainName: string | undefined;
  OriginAccessIdentity: string | undefined;
}
export interface StreamingDistributionConfig {
  CallerReference: string | undefined;
  S3Origin: S3Origin | undefined;
  Aliases?: Aliases;
  Comment: string | undefined;
  Logging?: StreamingLoggingConfig;
  TrustedSigners: TrustedSigners | undefined;
  PriceClass?: PriceClass;
  Enabled: boolean | undefined;
}
export interface CreateStreamingDistributionRequest {
  StreamingDistributionConfig: StreamingDistributionConfig | undefined;
}
export interface StreamingDistribution {
  Id: string | undefined;
  ARN: string | undefined;
  Status: string | undefined;
  LastModifiedTime?: Date;
  DomainName: string | undefined;
  ActiveTrustedSigners: ActiveTrustedSigners | undefined;
  StreamingDistributionConfig: StreamingDistributionConfig | undefined;
}
export interface CreateStreamingDistributionResult {
  StreamingDistribution?: StreamingDistribution;
  Location?: string;
  ETag?: string;
}
export declare class StreamingDistributionAlreadyExists extends __BaseException {
  readonly name: "StreamingDistributionAlreadyExists";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      StreamingDistributionAlreadyExists,
      __BaseException
    >
  );
}
export declare class TooManyStreamingDistributionCNAMEs extends __BaseException {
  readonly name: "TooManyStreamingDistributionCNAMEs";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      TooManyStreamingDistributionCNAMEs,
      __BaseException
    >
  );
}
export declare class TooManyStreamingDistributions extends __BaseException {
  readonly name: "TooManyStreamingDistributions";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<TooManyStreamingDistributions, __BaseException>
  );
}
export interface StreamingDistributionConfigWithTags {
  StreamingDistributionConfig: StreamingDistributionConfig | undefined;
  Tags: Tags | undefined;
}
export interface CreateStreamingDistributionWithTagsRequest {
  StreamingDistributionConfigWithTags:
    | StreamingDistributionConfigWithTags
    | undefined;
}
export interface CreateStreamingDistributionWithTagsResult {
  StreamingDistribution?: StreamingDistribution;
  Location?: string;
  ETag?: string;
}
export interface DeleteCachePolicyRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class IllegalDelete extends __BaseException {
  readonly name: "IllegalDelete";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<IllegalDelete, __BaseException>);
}
export declare class CloudFrontOriginAccessIdentityInUse extends __BaseException {
  readonly name: "CloudFrontOriginAccessIdentityInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      CloudFrontOriginAccessIdentityInUse,
      __BaseException
    >
  );
}
export interface DeleteCloudFrontOriginAccessIdentityRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class NoSuchCloudFrontOriginAccessIdentity extends __BaseException {
  readonly name: "NoSuchCloudFrontOriginAccessIdentity";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      NoSuchCloudFrontOriginAccessIdentity,
      __BaseException
    >
  );
}
export interface DeleteContinuousDeploymentPolicyRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export interface DeleteDistributionRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class DistributionNotDisabled extends __BaseException {
  readonly name: "DistributionNotDisabled";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<DistributionNotDisabled, __BaseException>
  );
}
export interface DeleteFieldLevelEncryptionConfigRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class FieldLevelEncryptionConfigInUse extends __BaseException {
  readonly name: "FieldLevelEncryptionConfigInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionConfigInUse,
      __BaseException
    >
  );
}
export interface DeleteFieldLevelEncryptionProfileRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class FieldLevelEncryptionProfileInUse extends __BaseException {
  readonly name: "FieldLevelEncryptionProfileInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      FieldLevelEncryptionProfileInUse,
      __BaseException
    >
  );
}
export interface DeleteFunctionRequest {
  Name: string | undefined;
  IfMatch: string | undefined;
}
export declare class FunctionInUse extends __BaseException {
  readonly name: "FunctionInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<FunctionInUse, __BaseException>);
}
export declare class NoSuchFunctionExists extends __BaseException {
  readonly name: "NoSuchFunctionExists";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<NoSuchFunctionExists, __BaseException>
  );
}
export interface DeleteKeyGroupRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class NoSuchResource extends __BaseException {
  readonly name: "NoSuchResource";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<NoSuchResource, __BaseException>);
}
export declare class ResourceInUse extends __BaseException {
  readonly name: "ResourceInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<ResourceInUse, __BaseException>);
}
export interface DeleteKeyValueStoreRequest {
  Name: string | undefined;
  IfMatch: string | undefined;
}
export declare class EntityNotFound extends __BaseException {
  readonly name: "EntityNotFound";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<EntityNotFound, __BaseException>);
}
export interface DeleteMonitoringSubscriptionRequest {
  DistributionId: string | undefined;
}
export interface DeleteMonitoringSubscriptionResult {}
export declare class NoSuchMonitoringSubscription extends __BaseException {
  readonly name: "NoSuchMonitoringSubscription";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<NoSuchMonitoringSubscription, __BaseException>
  );
}
export interface DeleteOriginAccessControlRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class NoSuchOriginAccessControl extends __BaseException {
  readonly name: "NoSuchOriginAccessControl";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<NoSuchOriginAccessControl, __BaseException>
  );
}
export declare class OriginAccessControlInUse extends __BaseException {
  readonly name: "OriginAccessControlInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<OriginAccessControlInUse, __BaseException>
  );
}
export interface DeleteOriginRequestPolicyRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class OriginRequestPolicyInUse extends __BaseException {
  readonly name: "OriginRequestPolicyInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<OriginRequestPolicyInUse, __BaseException>
  );
}
export interface DeletePublicKeyRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class PublicKeyInUse extends __BaseException {
  readonly name: "PublicKeyInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<PublicKeyInUse, __BaseException>);
}
export interface DeleteRealtimeLogConfigRequest {
  Name?: string;
  ARN?: string;
}
export declare class RealtimeLogConfigInUse extends __BaseException {
  readonly name: "RealtimeLogConfigInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<RealtimeLogConfigInUse, __BaseException>
  );
}
export interface DeleteResponseHeadersPolicyRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class ResponseHeadersPolicyInUse extends __BaseException {
  readonly name: "ResponseHeadersPolicyInUse";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<ResponseHeadersPolicyInUse, __BaseException>
  );
}
export interface DeleteStreamingDistributionRequest {
  Id: string | undefined;
  IfMatch?: string;
}
export declare class NoSuchStreamingDistribution extends __BaseException {
  readonly name: "NoSuchStreamingDistribution";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<NoSuchStreamingDistribution, __BaseException>
  );
}
export declare class StreamingDistributionNotDisabled extends __BaseException {
  readonly name: "StreamingDistributionNotDisabled";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      StreamingDistributionNotDisabled,
      __BaseException
    >
  );
}
export interface DescribeFunctionRequest {
  Name: string | undefined;
  Stage?: FunctionStage;
}
export interface DescribeFunctionResult {
  FunctionSummary?: FunctionSummary;
  ETag?: string;
}
export interface DescribeKeyValueStoreRequest {
  Name: string | undefined;
}
export interface DescribeKeyValueStoreResult {
  KeyValueStore?: KeyValueStore;
  ETag?: string;
}
export interface GetCachePolicyRequest {
  Id: string | undefined;
}
export interface GetCachePolicyResult {
  CachePolicy?: CachePolicy;
  ETag?: string;
}
export interface GetCachePolicyConfigRequest {
  Id: string | undefined;
}
export interface GetCachePolicyConfigResult {
  CachePolicyConfig?: CachePolicyConfig;
  ETag?: string;
}
export interface GetCloudFrontOriginAccessIdentityRequest {
  Id: string | undefined;
}
export interface GetCloudFrontOriginAccessIdentityResult {
  CloudFrontOriginAccessIdentity?: CloudFrontOriginAccessIdentity;
  ETag?: string;
}
export interface GetCloudFrontOriginAccessIdentityConfigRequest {
  Id: string | undefined;
}
export interface GetCloudFrontOriginAccessIdentityConfigResult {
  CloudFrontOriginAccessIdentityConfig?: CloudFrontOriginAccessIdentityConfig;
  ETag?: string;
}
export interface GetContinuousDeploymentPolicyRequest {
  Id: string | undefined;
}
export interface GetContinuousDeploymentPolicyResult {
  ContinuousDeploymentPolicy?: ContinuousDeploymentPolicy;
  ETag?: string;
}
export interface GetContinuousDeploymentPolicyConfigRequest {
  Id: string | undefined;
}
export interface GetContinuousDeploymentPolicyConfigResult {
  ContinuousDeploymentPolicyConfig?: ContinuousDeploymentPolicyConfig;
  ETag?: string;
}
export interface GetDistributionRequest {
  Id: string | undefined;
}
export interface GetDistributionResult {
  Distribution?: Distribution;
  ETag?: string;
}
export interface GetDistributionConfigRequest {
  Id: string | undefined;
}
export interface GetDistributionConfigResult {
  DistributionConfig?: DistributionConfig;
  ETag?: string;
}
export interface GetFieldLevelEncryptionRequest {
  Id: string | undefined;
}
export interface GetFieldLevelEncryptionResult {
  FieldLevelEncryption?: FieldLevelEncryption;
  ETag?: string;
}
export interface GetFieldLevelEncryptionConfigRequest {
  Id: string | undefined;
}
export interface GetFieldLevelEncryptionConfigResult {
  FieldLevelEncryptionConfig?: FieldLevelEncryptionConfig;
  ETag?: string;
}
export interface GetFieldLevelEncryptionProfileRequest {
  Id: string | undefined;
}
export interface GetFieldLevelEncryptionProfileResult {
  FieldLevelEncryptionProfile?: FieldLevelEncryptionProfile;
  ETag?: string;
}
export interface GetFieldLevelEncryptionProfileConfigRequest {
  Id: string | undefined;
}
export interface GetFieldLevelEncryptionProfileConfigResult {
  FieldLevelEncryptionProfileConfig?: FieldLevelEncryptionProfileConfig;
  ETag?: string;
}
export interface GetFunctionRequest {
  Name: string | undefined;
  Stage?: FunctionStage;
}
export interface GetFunctionResult {
  FunctionCode?: Uint8Array;
  ETag?: string;
  ContentType?: string;
}
export interface GetInvalidationRequest {
  DistributionId: string | undefined;
  Id: string | undefined;
}
export interface GetInvalidationResult {
  Invalidation?: Invalidation;
}
export declare class NoSuchInvalidation extends __BaseException {
  readonly name: "NoSuchInvalidation";
  readonly $fault: "client";
  Message?: string;
  constructor(opts: __ExceptionOptionType<NoSuchInvalidation, __BaseException>);
}
export interface GetKeyGroupRequest {
  Id: string | undefined;
}
export interface GetKeyGroupResult {
  KeyGroup?: KeyGroup;
  ETag?: string;
}
export interface GetKeyGroupConfigRequest {
  Id: string | undefined;
}
export interface GetKeyGroupConfigResult {
  KeyGroupConfig?: KeyGroupConfig;
  ETag?: string;
}
export interface GetMonitoringSubscriptionRequest {
  DistributionId: string | undefined;
}
export interface GetMonitoringSubscriptionResult {
  MonitoringSubscription?: MonitoringSubscription;
}
export interface GetOriginAccessControlRequest {
  Id: string | undefined;
}
export interface GetOriginAccessControlResult {
  OriginAccessControl?: OriginAccessControl;
  ETag?: string;
}
export interface GetOriginAccessControlConfigRequest {
  Id: string | undefined;
}
export interface GetOriginAccessControlConfigResult {
  OriginAccessControlConfig?: OriginAccessControlConfig;
  ETag?: string;
}
export interface GetOriginRequestPolicyRequest {
  Id: string | undefined;
}
export interface GetOriginRequestPolicyResult {
  OriginRequestPolicy?: OriginRequestPolicy;
  ETag?: string;
}
export interface GetOriginRequestPolicyConfigRequest {
  Id: string | undefined;
}
export interface GetOriginRequestPolicyConfigResult {
  OriginRequestPolicyConfig?: OriginRequestPolicyConfig;
  ETag?: string;
}
export interface GetPublicKeyRequest {
  Id: string | undefined;
}
export interface GetPublicKeyResult {
  PublicKey?: PublicKey;
  ETag?: string;
}
export interface GetPublicKeyConfigRequest {
  Id: string | undefined;
}
export interface GetPublicKeyConfigResult {
  PublicKeyConfig?: PublicKeyConfig;
  ETag?: string;
}
export interface GetRealtimeLogConfigRequest {
  Name?: string;
  ARN?: string;
}
export interface GetRealtimeLogConfigResult {
  RealtimeLogConfig?: RealtimeLogConfig;
}
export interface GetResponseHeadersPolicyRequest {
  Id: string | undefined;
}
export interface GetResponseHeadersPolicyResult {
  ResponseHeadersPolicy?: ResponseHeadersPolicy;
  ETag?: string;
}
export interface GetResponseHeadersPolicyConfigRequest {
  Id: string | undefined;
}
export interface GetResponseHeadersPolicyConfigResult {
  ResponseHeadersPolicyConfig?: ResponseHeadersPolicyConfig;
  ETag?: string;
}
export interface GetStreamingDistributionRequest {
  Id: string | undefined;
}
export interface GetStreamingDistributionResult {
  StreamingDistribution?: StreamingDistribution;
  ETag?: string;
}
export interface GetStreamingDistributionConfigRequest {
  Id: string | undefined;
}
export interface GetStreamingDistributionConfigResult {
  StreamingDistributionConfig?: StreamingDistributionConfig;
  ETag?: string;
}
export interface ListCachePoliciesRequest {
  Type?: CachePolicyType;
  Marker?: string;
  MaxItems?: number;
}
export interface ListCachePoliciesResult {
  CachePolicyList?: CachePolicyList;
}
export interface ListCloudFrontOriginAccessIdentitiesRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface CloudFrontOriginAccessIdentitySummary {
  Id: string | undefined;
  S3CanonicalUserId: string | undefined;
  Comment: string | undefined;
}
export interface CloudFrontOriginAccessIdentityList {
  Marker: string | undefined;
  NextMarker?: string;
  MaxItems: number | undefined;
  IsTruncated: boolean | undefined;
  Quantity: number | undefined;
  Items?: CloudFrontOriginAccessIdentitySummary[];
}
export interface ListCloudFrontOriginAccessIdentitiesResult {
  CloudFrontOriginAccessIdentityList?: CloudFrontOriginAccessIdentityList;
}
export interface ListConflictingAliasesRequest {
  DistributionId: string | undefined;
  Alias: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface ConflictingAlias {
  Alias?: string;
  DistributionId?: string;
  AccountId?: string;
}
export interface ConflictingAliasesList {
  NextMarker?: string;
  MaxItems?: number;
  Quantity?: number;
  Items?: ConflictingAlias[];
}
export interface ListConflictingAliasesResult {
  ConflictingAliasesList?: ConflictingAliasesList;
}
export interface ListContinuousDeploymentPoliciesRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface ContinuousDeploymentPolicySummary {
  ContinuousDeploymentPolicy: ContinuousDeploymentPolicy | undefined;
}
export interface ContinuousDeploymentPolicyList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: ContinuousDeploymentPolicySummary[];
}
export interface ListContinuousDeploymentPoliciesResult {
  ContinuousDeploymentPolicyList?: ContinuousDeploymentPolicyList;
}
export interface ListDistributionsRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface DistributionSummary {
  Id: string | undefined;
  ARN: string | undefined;
  Status: string | undefined;
  LastModifiedTime: Date | undefined;
  DomainName: string | undefined;
  Aliases: Aliases | undefined;
  Origins: Origins | undefined;
  OriginGroups?: OriginGroups;
  DefaultCacheBehavior: DefaultCacheBehavior | undefined;
  CacheBehaviors: CacheBehaviors | undefined;
  CustomErrorResponses: CustomErrorResponses | undefined;
  Comment: string | undefined;
  PriceClass: PriceClass | undefined;
  Enabled: boolean | undefined;
  ViewerCertificate: ViewerCertificate | undefined;
  Restrictions: Restrictions | undefined;
  WebACLId: string | undefined;
  HttpVersion: HttpVersion | undefined;
  IsIPV6Enabled: boolean | undefined;
  AliasICPRecordals?: AliasICPRecordal[];
  Staging: boolean | undefined;
}
export interface DistributionList {
  Marker: string | undefined;
  NextMarker?: string;
  MaxItems: number | undefined;
  IsTruncated: boolean | undefined;
  Quantity: number | undefined;
  Items?: DistributionSummary[];
}
export interface ListDistributionsResult {
  DistributionList?: DistributionList;
}
export interface ListDistributionsByCachePolicyIdRequest {
  Marker?: string;
  MaxItems?: number;
  CachePolicyId: string | undefined;
}
export interface DistributionIdList {
  Marker: string | undefined;
  NextMarker?: string;
  MaxItems: number | undefined;
  IsTruncated: boolean | undefined;
  Quantity: number | undefined;
  Items?: string[];
}
export interface ListDistributionsByCachePolicyIdResult {
  DistributionIdList?: DistributionIdList;
}
export interface ListDistributionsByKeyGroupRequest {
  Marker?: string;
  MaxItems?: number;
  KeyGroupId: string | undefined;
}
export interface ListDistributionsByKeyGroupResult {
  DistributionIdList?: DistributionIdList;
}
export interface ListDistributionsByOriginRequestPolicyIdRequest {
  Marker?: string;
  MaxItems?: number;
  OriginRequestPolicyId: string | undefined;
}
export interface ListDistributionsByOriginRequestPolicyIdResult {
  DistributionIdList?: DistributionIdList;
}
export interface ListDistributionsByRealtimeLogConfigRequest {
  Marker?: string;
  MaxItems?: number;
  RealtimeLogConfigName?: string;
  RealtimeLogConfigArn?: string;
}
export interface ListDistributionsByRealtimeLogConfigResult {
  DistributionList?: DistributionList;
}
export interface ListDistributionsByResponseHeadersPolicyIdRequest {
  Marker?: string;
  MaxItems?: number;
  ResponseHeadersPolicyId: string | undefined;
}
export interface ListDistributionsByResponseHeadersPolicyIdResult {
  DistributionIdList?: DistributionIdList;
}
export interface ListDistributionsByWebACLIdRequest {
  Marker?: string;
  MaxItems?: number;
  WebACLId: string | undefined;
}
export interface ListDistributionsByWebACLIdResult {
  DistributionList?: DistributionList;
}
export interface ListFieldLevelEncryptionConfigsRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface FieldLevelEncryptionSummary {
  Id: string | undefined;
  LastModifiedTime: Date | undefined;
  Comment?: string;
  QueryArgProfileConfig?: QueryArgProfileConfig;
  ContentTypeProfileConfig?: ContentTypeProfileConfig;
}
export interface FieldLevelEncryptionList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: FieldLevelEncryptionSummary[];
}
export interface ListFieldLevelEncryptionConfigsResult {
  FieldLevelEncryptionList?: FieldLevelEncryptionList;
}
export interface ListFieldLevelEncryptionProfilesRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface FieldLevelEncryptionProfileSummary {
  Id: string | undefined;
  LastModifiedTime: Date | undefined;
  Name: string | undefined;
  EncryptionEntities: EncryptionEntities | undefined;
  Comment?: string;
}
export interface FieldLevelEncryptionProfileList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: FieldLevelEncryptionProfileSummary[];
}
export interface ListFieldLevelEncryptionProfilesResult {
  FieldLevelEncryptionProfileList?: FieldLevelEncryptionProfileList;
}
export interface ListFunctionsRequest {
  Marker?: string;
  MaxItems?: number;
  Stage?: FunctionStage;
}
export interface FunctionList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: FunctionSummary[];
}
export interface ListFunctionsResult {
  FunctionList?: FunctionList;
}
export interface ListInvalidationsRequest {
  DistributionId: string | undefined;
  Marker?: string;
  MaxItems?: number;
}
export interface InvalidationSummary {
  Id: string | undefined;
  CreateTime: Date | undefined;
  Status: string | undefined;
}
export interface InvalidationList {
  Marker: string | undefined;
  NextMarker?: string;
  MaxItems: number | undefined;
  IsTruncated: boolean | undefined;
  Quantity: number | undefined;
  Items?: InvalidationSummary[];
}
export interface ListInvalidationsResult {
  InvalidationList?: InvalidationList;
}
export interface ListKeyGroupsRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface KeyGroupSummary {
  KeyGroup: KeyGroup | undefined;
}
export interface KeyGroupList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: KeyGroupSummary[];
}
export interface ListKeyGroupsResult {
  KeyGroupList?: KeyGroupList;
}
export interface ListKeyValueStoresRequest {
  Marker?: string;
  MaxItems?: number;
  Status?: string;
}
export interface KeyValueStoreList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: KeyValueStore[];
}
export interface ListKeyValueStoresResult {
  KeyValueStoreList?: KeyValueStoreList;
}
export interface ListOriginAccessControlsRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface OriginAccessControlSummary {
  Id: string | undefined;
  Description: string | undefined;
  Name: string | undefined;
  SigningProtocol: OriginAccessControlSigningProtocols | undefined;
  SigningBehavior: OriginAccessControlSigningBehaviors | undefined;
  OriginAccessControlOriginType: OriginAccessControlOriginTypes | undefined;
}
export interface OriginAccessControlList {
  Marker: string | undefined;
  NextMarker?: string;
  MaxItems: number | undefined;
  IsTruncated: boolean | undefined;
  Quantity: number | undefined;
  Items?: OriginAccessControlSummary[];
}
export interface ListOriginAccessControlsResult {
  OriginAccessControlList?: OriginAccessControlList;
}
export declare const OriginRequestPolicyType: {
  readonly custom: "custom";
  readonly managed: "managed";
};
export type OriginRequestPolicyType =
  (typeof OriginRequestPolicyType)[keyof typeof OriginRequestPolicyType];
export interface ListOriginRequestPoliciesRequest {
  Type?: OriginRequestPolicyType;
  Marker?: string;
  MaxItems?: number;
}
export interface OriginRequestPolicySummary {
  Type: OriginRequestPolicyType | undefined;
  OriginRequestPolicy: OriginRequestPolicy | undefined;
}
export interface OriginRequestPolicyList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: OriginRequestPolicySummary[];
}
export interface ListOriginRequestPoliciesResult {
  OriginRequestPolicyList?: OriginRequestPolicyList;
}
export interface ListPublicKeysRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface PublicKeySummary {
  Id: string | undefined;
  Name: string | undefined;
  CreatedTime: Date | undefined;
  EncodedKey: string | undefined;
  Comment?: string;
}
export interface PublicKeyList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: PublicKeySummary[];
}
export interface ListPublicKeysResult {
  PublicKeyList?: PublicKeyList;
}
export interface ListRealtimeLogConfigsRequest {
  MaxItems?: number;
  Marker?: string;
}
export interface RealtimeLogConfigs {
  MaxItems: number | undefined;
  Items?: RealtimeLogConfig[];
  IsTruncated: boolean | undefined;
  Marker: string | undefined;
  NextMarker?: string;
}
export interface ListRealtimeLogConfigsResult {
  RealtimeLogConfigs?: RealtimeLogConfigs;
}
export declare const ResponseHeadersPolicyType: {
  readonly custom: "custom";
  readonly managed: "managed";
};
export type ResponseHeadersPolicyType =
  (typeof ResponseHeadersPolicyType)[keyof typeof ResponseHeadersPolicyType];
export interface ListResponseHeadersPoliciesRequest {
  Type?: ResponseHeadersPolicyType;
  Marker?: string;
  MaxItems?: number;
}
export interface ResponseHeadersPolicySummary {
  Type: ResponseHeadersPolicyType | undefined;
  ResponseHeadersPolicy: ResponseHeadersPolicy | undefined;
}
export interface ResponseHeadersPolicyList {
  NextMarker?: string;
  MaxItems: number | undefined;
  Quantity: number | undefined;
  Items?: ResponseHeadersPolicySummary[];
}
export interface ListResponseHeadersPoliciesResult {
  ResponseHeadersPolicyList?: ResponseHeadersPolicyList;
}
export interface ListStreamingDistributionsRequest {
  Marker?: string;
  MaxItems?: number;
}
export interface StreamingDistributionSummary {
  Id: string | undefined;
  ARN: string | undefined;
  Status: string | undefined;
  LastModifiedTime: Date | undefined;
  DomainName: string | undefined;
  S3Origin: S3Origin | undefined;
  Aliases: Aliases | undefined;
  TrustedSigners: TrustedSigners | undefined;
  Comment: string | undefined;
  PriceClass: PriceClass | undefined;
  Enabled: boolean | undefined;
}
export interface StreamingDistributionList {
  Marker: string | undefined;
  NextMarker?: string;
  MaxItems: number | undefined;
  IsTruncated: boolean | undefined;
  Quantity: number | undefined;
  Items?: StreamingDistributionSummary[];
}
export interface ListStreamingDistributionsResult {
  StreamingDistributionList?: StreamingDistributionList;
}
export interface ListTagsForResourceRequest {
  Resource: string | undefined;
}
export interface ListTagsForResourceResult {
  Tags: Tags | undefined;
}
export interface PublishFunctionRequest {
  Name: string | undefined;
  IfMatch: string | undefined;
}
export interface PublishFunctionResult {
  FunctionSummary?: FunctionSummary;
}
export interface TagResourceRequest {
  Resource: string | undefined;
  Tags: Tags | undefined;
}
export declare class TestFunctionFailed extends __BaseException {
  readonly name: "TestFunctionFailed";
  readonly $fault: "server";
  Message?: string;
  constructor(opts: __ExceptionOptionType<TestFunctionFailed, __BaseException>);
}
export interface TestFunctionRequest {
  Name: string | undefined;
  IfMatch: string | undefined;
  Stage?: FunctionStage;
  EventObject: Uint8Array | undefined;
}
export interface TestResult {
  FunctionSummary?: FunctionSummary;
  ComputeUtilization?: string;
  FunctionExecutionLogs?: string[];
  FunctionErrorMessage?: string;
  FunctionOutput?: string;
}
export interface TestFunctionResult {
  TestResult?: TestResult;
}
export interface TagKeys {
  Items?: string[];
}
export interface UntagResourceRequest {
  Resource: string | undefined;
  TagKeys: TagKeys | undefined;
}
export interface UpdateCachePolicyRequest {
  CachePolicyConfig: CachePolicyConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateCachePolicyResult {
  CachePolicy?: CachePolicy;
  ETag?: string;
}
export interface UpdateCloudFrontOriginAccessIdentityRequest {
  CloudFrontOriginAccessIdentityConfig:
    | CloudFrontOriginAccessIdentityConfig
    | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateCloudFrontOriginAccessIdentityResult {
  CloudFrontOriginAccessIdentity?: CloudFrontOriginAccessIdentity;
  ETag?: string;
}
export interface UpdateContinuousDeploymentPolicyRequest {
  ContinuousDeploymentPolicyConfig:
    | ContinuousDeploymentPolicyConfig
    | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateContinuousDeploymentPolicyResult {
  ContinuousDeploymentPolicy?: ContinuousDeploymentPolicy;
  ETag?: string;
}
export interface UpdateDistributionRequest {
  DistributionConfig: DistributionConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateDistributionResult {
  Distribution?: Distribution;
  ETag?: string;
}
export interface UpdateDistributionWithStagingConfigRequest {
  Id: string | undefined;
  StagingDistributionId?: string;
  IfMatch?: string;
}
export interface UpdateDistributionWithStagingConfigResult {
  Distribution?: Distribution;
  ETag?: string;
}
export interface UpdateFieldLevelEncryptionConfigRequest {
  FieldLevelEncryptionConfig: FieldLevelEncryptionConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateFieldLevelEncryptionConfigResult {
  FieldLevelEncryption?: FieldLevelEncryption;
  ETag?: string;
}
export interface UpdateFieldLevelEncryptionProfileRequest {
  FieldLevelEncryptionProfileConfig:
    | FieldLevelEncryptionProfileConfig
    | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateFieldLevelEncryptionProfileResult {
  FieldLevelEncryptionProfile?: FieldLevelEncryptionProfile;
  ETag?: string;
}
export interface UpdateFunctionRequest {
  Name: string | undefined;
  IfMatch: string | undefined;
  FunctionConfig: FunctionConfig | undefined;
  FunctionCode: Uint8Array | undefined;
}
export interface UpdateFunctionResult {
  FunctionSummary?: FunctionSummary;
  ETag?: string;
}
export interface UpdateKeyGroupRequest {
  KeyGroupConfig: KeyGroupConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateKeyGroupResult {
  KeyGroup?: KeyGroup;
  ETag?: string;
}
export interface UpdateKeyValueStoreRequest {
  Name: string | undefined;
  Comment: string | undefined;
  IfMatch: string | undefined;
}
export interface UpdateKeyValueStoreResult {
  KeyValueStore?: KeyValueStore;
  ETag?: string;
}
export interface UpdateOriginAccessControlRequest {
  OriginAccessControlConfig: OriginAccessControlConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateOriginAccessControlResult {
  OriginAccessControl?: OriginAccessControl;
  ETag?: string;
}
export interface UpdateOriginRequestPolicyRequest {
  OriginRequestPolicyConfig: OriginRequestPolicyConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateOriginRequestPolicyResult {
  OriginRequestPolicy?: OriginRequestPolicy;
  ETag?: string;
}
export interface UpdatePublicKeyRequest {
  PublicKeyConfig: PublicKeyConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdatePublicKeyResult {
  PublicKey?: PublicKey;
  ETag?: string;
}
export interface UpdateRealtimeLogConfigRequest {
  EndPoints?: EndPoint[];
  Fields?: string[];
  Name?: string;
  ARN?: string;
  SamplingRate?: number;
}
export interface UpdateRealtimeLogConfigResult {
  RealtimeLogConfig?: RealtimeLogConfig;
}
export interface UpdateResponseHeadersPolicyRequest {
  ResponseHeadersPolicyConfig: ResponseHeadersPolicyConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateResponseHeadersPolicyResult {
  ResponseHeadersPolicy?: ResponseHeadersPolicy;
  ETag?: string;
}
export interface UpdateStreamingDistributionRequest {
  StreamingDistributionConfig: StreamingDistributionConfig | undefined;
  Id: string | undefined;
  IfMatch?: string;
}
export interface UpdateStreamingDistributionResult {
  StreamingDistribution?: StreamingDistribution;
  ETag?: string;
}
export declare const GetDistributionResultFilterSensitiveLog: (
  obj: GetDistributionResult
) => any;
export declare const GetDistributionConfigResultFilterSensitiveLog: (
  obj: GetDistributionConfigResult
) => any;
export declare const GetFunctionResultFilterSensitiveLog: (
  obj: GetFunctionResult
) => any;
export declare const DistributionSummaryFilterSensitiveLog: (
  obj: DistributionSummary
) => any;
export declare const DistributionListFilterSensitiveLog: (
  obj: DistributionList
) => any;
export declare const ListDistributionsResultFilterSensitiveLog: (
  obj: ListDistributionsResult
) => any;
export declare const ListDistributionsByRealtimeLogConfigResultFilterSensitiveLog: (
  obj: ListDistributionsByRealtimeLogConfigResult
) => any;
export declare const ListDistributionsByWebACLIdResultFilterSensitiveLog: (
  obj: ListDistributionsByWebACLIdResult
) => any;
export declare const TestFunctionRequestFilterSensitiveLog: (
  obj: TestFunctionRequest
) => any;
export declare const TestResultFilterSensitiveLog: (obj: TestResult) => any;
export declare const TestFunctionResultFilterSensitiveLog: (
  obj: TestFunctionResult
) => any;
export declare const UpdateDistributionRequestFilterSensitiveLog: (
  obj: UpdateDistributionRequest
) => any;
export declare const UpdateDistributionResultFilterSensitiveLog: (
  obj: UpdateDistributionResult
) => any;
export declare const UpdateDistributionWithStagingConfigResultFilterSensitiveLog: (
  obj: UpdateDistributionWithStagingConfigResult
) => any;
export declare const UpdateFunctionRequestFilterSensitiveLog: (
  obj: UpdateFunctionRequest
) => any;
