import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { CloudFrontClientResolvedConfig } from "../CloudFrontClient";
/**
 * @internal
 */
export interface CloudFrontHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface CloudFrontHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<CloudFrontClientResolvedConfig, HandlerExecutionContext, CloudFrontHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultCloudFrontHttpAuthSchemeParametersProvider: (config: CloudFrontClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<CloudFrontHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface CloudFrontHttpAuthSchemeProvider extends HttpAuthSchemeProvider<CloudFrontHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultCloudFrontHttpAuthSchemeProvider: CloudFrontHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: CloudFrontHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: CloudFrontHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
