"use strict";
/**
 * server.js
 *
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dgram_1 = require("dgram");
const packet_1 = require("./packet");
const message_types_1 = __importDefault(require("../lib/packet/message-types"));
const util_1 = require("util");
/**
 *
 */
class DHCPServer extends dgram_1.Socket {
    constructor(type, opts) {
        super(type);
        var _this = this;
        _this.broadcast = opts.broadcast;
        this.on('error', function (err) {
            console.dir(err);
        });
        this.on('message', function (buffer, remote) {
            var event_name, packet, type;
            packet = packet_1.Packet.fromBuffer(buffer);
            if (packet.op === 1) {
                type = {
                    id: packet.options[53] || 0,
                    name: message_types_1.default[packet.options[53] || 0]
                };
                (0, util_1.log)(("Got " + type.name + " from") + (" " + remote.address + ":" + remote.port + " (" + packet.chaddr + ") ") + (" with packet length of " + buffer.length + " bytes"));
                event_name = type.name.replace('DHCP', '').toLowerCase();
                packet.remote = remote;
                return _this._emitPacket(event_name, packet);
            }
            else {
                return console.log("  Unsupported message format");
            }
        });
        return _this;
    }
    /**
     *
     * @param {*} port
     * @param {*} addr
     * @param {*} cb
     * @returns
     */
    bind(port, addr, cb) {
        var self = this;
        var res;
        // Andrebbe sostituito... 
        res = DHCPServer.super_.prototype.bind.call(this, port, addr, function () {
            this.setBroadcast(true);
            if (cb instanceof Function)
                cb();
        });
        return res;
    }
    /**
     *
     * @param {*} event_name
     * @param {*} ip
     * @param {*} packet
     * @returns
     */
    _send(event_name, ip, packet) {
        var buffer, _this = this;
        buffer = packet.toBuffer();
        (0, util_1.log)(("Sending " + message_types_1.default[packet.options[53]]) + (" to " + ip + ":68 (" + packet.chaddr + ")") + (" with packet length of " + buffer.length + " bytes"));
        this.emit(event_name, packet);
        return this.send(buffer, 0, buffer.length, 68, ip, function (err, bytes) {
            if (err) {
                return _this.emit("" + event_name + "Error", err, packet);
            }
            else {
                return _this.emit("" + event_name + "Sent", bytes, packet);
            }
        });
    }
    /**
     *
     * @param {*} message_type
     * @param {*} packet
     * @returns
     */
    _emitPacket(message_type, packet) {
        return this.emit(message_type, packet, packet.options[50] || null);
    }
    /**
     *
     * @param {*} packet
     * @param {*} params
     */
    discover(packet, params) {
        console.log('Got DHCP DISCOVER');
    }
    /**
     *
     * @param {*} packet
     * @param {*} params
     * @returns
     */
    offer(packet, params) {
        if (params) {
            packet.yiaddr = params.yiaddr;
            packet.siaddr = params.siaddr;
            packet.options = params.options;
        }
        packet.op = packet.options[53] = 2;
        //return this._send('offer', this.broadcast, packet);
        return this._send('offer', '255.255.255.255', packet);
    }
    /**
     *
     * @param {*} packet
     * @param {*} params
     * @returns
     */
    ack(packet, params) {
        if (params) {
            packet.yiaddr = params.yiaddr;
            packet.siaddr = params.siaddr;
            packet.options = params.options;
        }
        packet.op = 2;
        packet.options[53] = 5;
        return this._send('ack', this.broadcast, packet);
    }
    /**
     *
     * @param {*} packet
     * @param {*} params
     * @returns
     */
    nak(packet, params) {
        packet.op = 2;
        packet.options[53] = 6;
        return this._send('nak', packet.ciaddr, packet);
    }
    /**
     *
     * @param {*} packet
     * @param {*} params
     * @returns
     */
    inform(packet, params) {
        if (params) {
            packet.yiaddr = params.yiaddr;
            packet.siaddr = params.siaddr;
            packet.options = params.options;
        }
        packet.op = 2;
        packet.options[53] = 5;
        return this._send('inform', packet.ciaddr, packet);
    }
}
/**
 * Poichè DHCPServer extents Socket non dovrebbe essere
 * più necessario, lo mantengo, finchè non trovo il
 * modo di sostituire:
 *
 * res = DHCPServer.super_.prototype.bind.call(this, port, addr, function () {
  */
(0, util_1.inherits)(DHCPServer, dgram_1.Socket);
DHCPServer.Packet = packet_1.Packet;
exports.default = DHCPServer;
