"use strict";
/**
 * util.ts
 *
 * used in dhcpd
 *
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeString = exports.writeIp = exports.writeTimeOffset = exports.readMacAddress = exports.readIp = exports.readHexAddress = exports.readHex = exports.readString = exports.readInt8 = exports.readInt16 = exports.readInt32 = exports.readBytes = exports.writeInt8 = exports.writeInt16 = exports.writeInt32 = exports.writeBytes = void 0;
const sprintf_1 = __importDefault(require("./sprintf"));
/**
 *
 * @param _buffer
 * @param byteArray
 * @param offset
 * @returns
 */
const writeBytes = (_buffer, byteArray, offset) => {
    let _bytesWritten = 0;
    let i = 0;
    while (i < byteArray.length) {
        _buffer[offset++] = byteArray[i];
        i++;
    }
    if (offset > _bytesWritten) {
        _bytesWritten = offset;
    }
    return this;
};
exports.writeBytes = writeBytes;
/**
 *
 * @param _buffer
 * @param integer
 * @param offset
 * @returns
 */
function writeInt32(_buffer, integer, offset) {
    _buffer[offset++] = integer >>> 24;
    _buffer[offset++] = integer >>> 16;
    _buffer[offset++] = integer >>> 8;
    _buffer[offset++] = integer;
    return offset;
}
exports.writeInt32 = writeInt32;
/**
 *
 * @param _buffer
 * @param integer
 * @param offset
 * @returns
 */
function writeInt16(_buffer, integer, offset) {
    _buffer[offset++] = integer >>> 8;
    _buffer[offset++] = integer;
    return offset;
}
exports.writeInt16 = writeInt16;
/**
 *
 * @param _buffer
 * @param integer
 * @param offset
 * @returns
 */
function writeInt8(_buffer, integer, offset) {
    _buffer[offset++] = integer;
    return offset;
}
exports.writeInt8 = writeInt8;
/**
 *
 * @param _buffer
 * @param length
 * @param copy
 * @param offset
 * @returns
 */
function readBytes(_buffer, length, copy, offset) {
    let bufCopy;
    if (copy) {
        bufCopy = new Buffer(length);
        _buffer.copy(bufCopy, 0, offset, (offset += length));
        return bufCopy;
    }
    else {
        return _buffer.slice(offset, (offset += length));
    }
}
exports.readBytes = readBytes;
/**
 *
 * @param _buffer
 * @param offset
 * @returns
 */
function readInt32(_buffer, offset) {
    return (_buffer[offset++] << 24) | (_buffer[offset++] << 16) | (_buffer[offset++] << 8) | _buffer[offset++];
}
exports.readInt32 = readInt32;
/**
 *
 * @param _buffer
 * @param offset
 * @returns
 */
function readInt16(_buffer, offset) {
    return (_buffer[offset++] << 8) | _buffer[offset++];
}
exports.readInt16 = readInt16;
/**
 *
 * @param _buffer
 * @param offset
 * @returns
 */
function readInt8(_buffer, offset) {
    return _buffer[offset++];
}
exports.readInt8 = readInt8;
/**
 *
 * @param buf
 * @returns
 */
function readString(buf) {
    let j, s;
    s = "";
    j = 0;
    while (j < buf.length) {
        s += String.fromCharCode(buf[j]);
        j++;
    }
    return s;
}
exports.readString = readString;
/**
 *
 * @param buf
 * @returns
 */
function readHex(buf) {
    let j, s;
    s = "";
    j = 0;
    while (j < buf.length) {
        // check was b not buf
        s += (0, sprintf_1.default)("%02x", buf[j]);
        j++;
    }
    return s;
}
exports.readHex = readHex;
/**
 *
 * @param buf
 * @returns
 */
function readHexAddress(buf) {
    let j, s;
    s = [];
    j = 0;
    while (j < buf.length) {
        s.push((0, sprintf_1.default)("%02d", buf[j]));
        j++;
    }
    return s.join(":");
}
exports.readHexAddress = readHexAddress;
/**
 *
 * @param buffer
 * @param offset
 * @returns
 */
function readIp(buffer, offset) {
    let stop;
    if (offset === null) {
        offset = 0;
    }
    if (offset > buffer.length) {
        return undefined;
    }
    if (0 === buffer.readUInt8(offset)) {
        return undefined;
    }
    else {
        stop = offset + 4;
        return ((function () {
            const _results = [];
            while (offset < stop) {
                _results.push(buffer.readUInt8(offset++));
            }
            return _results;
        })()).join('.');
    }
}
exports.readIp = readIp;
/**
 *
 * @param buffer
 * @returns
 */
function readMacAddress(buffer) {
    let byte;
    return ((function () {
        let _i, _len;
        const _results = [];
        for (_i = 0, _len = buffer.length; _i < _len; _i++) {
            byte = buffer[_i];
            _results.push((byte + 0x100).toString(16).substr(-2));
        }
        return _results;
    })()).join(':');
}
exports.readMacAddress = readMacAddress;
/**
 *
 * @param buf
 * @param num
 * @param offsetHours
 * @param offset
 * @returns
 */
function writeTimeOffset(buf, num, offsetHours, offset) {
    buf[offset++] = 0;
    return offset;
}
exports.writeTimeOffset = writeTimeOffset;
/**
 *
 * @param buf
 * @param num
 * @param ip
 * @param offset
 * @returns
 */
function writeIp(buf, num, ip, offset) {
    buf[offset++] = num;
    buf[offset++] = 4;
    if ((typeof ip !== 'string' && !(ip instanceof String)) || ip.indexOf('.') === -1) {
        ip = "0.0.0.0";
    }
    ip.split(".").forEach(function (item) {
        buf[offset++] = item;
    });
    return offset;
}
exports.writeIp = writeIp;
/**
 *
 * @param buf
 * @param num
 * @param hostname
 * @param offset
 * @returns
 */
function writeString(buf, num, hostname, offset) {
    let charArr;
    charArr = hostname.split("");
    buf[offset++] = num;
    buf[offset++] = charArr.length;
    charArr.forEach(function (chr) {
        // charCodeAt(index: number): number
        //buf[offset++] = chr.charCodeAt() original
        buf[offset++] = chr.charCodeAt(0);
    });
    return offset;
}
exports.writeString = writeString;
