"use strict";
/**
 * Executes shell command as it would happen in BASH script
 * @param {string} command
 * @param {Object} [options] Object with options.
 *                           Set `echo` to TRUE, to echo command passed.
 *                           Set `ignore` to TRUE to ignore stdout
 *                           Set `capture` to TRUE, to capture and return stdout.
 *
 * @returns {Promise<{code: number, data: string | undefined, error: Object}>}
 *
 * https://github.com/oclif/core/issues/453#issuecomment-1200778612
 * codespool:
 * You could wrap spawn in a promise, listen to exit event, and resolve when it happens. That should play nicely with oclif/core.
 * We are using it here:
 * https://github.com/AstarNetwork/swanky-cli/blob/master/src/commands/compile/index.ts
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.exec = void 0;
const child_process_1 = require("child_process");
/**
 *
 * @param command
 * @param param1
 * @returns
 */
async function exec(command, { capture = false, echo = false, ignore = false } = {}) {
    /**
     * You could wrap spawn in a promise,
     * listen to exit event,
     * and resolve when it happens.
     *
     * That should play nicely with oclif/core.
     */
    return new Promise((resolve, reject) => {
        if (echo) {
            console.log(command);
        }
        const child = (0, child_process_1.spawn)('bash', ['-c', command], {
            stdio: ignore ? 'ignore' : (capture ? 'pipe' : 'inherit'),
        });
        // const spawn = require('child_process').spawn
        // child.stdout.on('data', (data: string) => {
        let stdout = '';
        if (capture) {
            child.stdout?.on('data', (data) => {
                stdout += data;
            });
        }
        // 'error' event
        child.on('error', (error) => {
            reject({ code: 1, error });
        });
        // The 'exit' event is emitted after the child process ends. If the process exited, code is the final exit code of the process,
        // otherwise null. If the process terminated due to receipt of a signal, signal is the string name of the signal, otherwise null.
        // One of the two will always be non-null.
        child.on('exit', (code) => {
            resolve({ code, data: stdout });
        });
        // end promise
    });
}
exports.exec = exec;
